<?php

load_theme_textdomain('lalala');

/* [caption]タグを挿入させない */
add_filter('disable_captions', create_function('','return true;'));


/* link-template.php の関数を改造 --- 直接出力せず値を返すようにした。 */
function next_posts_rt($max_page = 0) {
	return clean_url(get_next_posts_page_link($max_page));
}

function next_posts_link_rt($label='Next Page &raquo;', $max_page=0) {
	global $paged, $wp_query;
	if ( !$max_page ) {
		$max_page = $wp_query->max_num_pages;
	}
	if ( !$paged )
		$paged = 1;
	$nextpage = intval($paged) + 1;
	if ( (! is_single()) && (empty($paged) || $nextpage <= $max_page) ) {
		$s= '<a href="';
		$s .= next_posts_rt($max_page);
		$s.= '">'. preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
		return $s;
	}
}

function previous_posts_rt() {
	return clean_url(get_previous_posts_page_link());
}

function previous_posts_link_rt($label='&laquo; Previous Page') {
	global $paged;
	if ( (!is_single())	&& ($paged > 1) ) {
		$s= '<a href="';
		$s .= previous_posts_rt();
		$s .= '">'. preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
		return $s;
	}
}

function previous_post_link_rt($format='&laquo; %link', $link='%title', $in_same_cat = false, $excluded_categories = '') {
	return adjacent_post_link_rt($format, $link, $in_same_cat, $excluded_categories, true);
}

function next_post_link_rt($format='%link &raquo;', $link='%title', $in_same_cat = false, $excluded_categories = '') {
	return adjacent_post_link_rt($format, $link, $in_same_cat, $excluded_categories, false);
}

function adjacent_post_link_rt($format, $link, $in_same_cat = false, $excluded_categories = '', $previous = true) {
	if ( $previous && is_attachment() )
		$post = & get_post($GLOBALS['post']->post_parent);
	else
		$post = get_adjacent_post($in_same_cat, $excluded_categories, $previous);

	if ( !$post )
		return;

	$title = $post->post_title;

	if ( empty($post->post_title) )
		$title = $previous ? __('Previous Post') : __('Next Post');

	$title = apply_filters('the_title', $title, $post);
	$string = '<a href="'.get_permalink($post).'">';
	$link = str_replace('%title', $title, $link);
	$link = $string . $link . '</a>';

	$format = str_replace('%link', $link, $format);

	return $format;
}
/**
 * Display link to next comments pages.
 *
 * @since 2.7.0
 *
 * @param string $label Optional. Label for link text.
 * @param int $max_page Optional. Max page.
 * next_comments_link の改造。直接出力せず値を返す。
 */
function next_comments_link_rt($label='', $max_page = 0) {
	global $wp_query;

	if ( !is_singular() )
		return;

	$page = get_query_var('cpage');

	if ( !$page )
		$page = 1;

	$nextpage = intval($page) + 1;

	if ( empty($max_page) )
		$max_page = $wp_query->max_num_comment_pages;

	if ( empty($max_page) )
		$max_page = get_comment_pages_count();

	if ( $nextpage > $max_page )
		return;

	if ( empty($label) )
		$label = __('Newer Comments &raquo;');

	$rt= '<a href="' . clean_url( get_comments_pagenum_link( $nextpage, $max_page ) );
	$attr = apply_filters( 'next_comments_link_attributes', '' );
	$rt.= "\" $attr>". preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';

	return $rt;
}

/**
 * Display the previous comments page link.
 *
 * @since 2.7.0
 *
 * @param string $label Optional. Label for comments link text.
 * previous_comments_link の改造。直接出力せず値を返す。
 */
function previous_comments_link_rt($label='') {

	if ( !is_singular() )
		return;

	$page = get_query_var('cpage');

	if ( !$page )
		$page = 1;

	if ( $page <= 1 )
		return;

	$prevpage = intval($page) - 1;

	if ( empty($label) )
		$label = __('&laquo; Older Comments');

	$rt= '<a href="' . clean_url(get_comments_pagenum_link($prevpage));
	$attr = apply_filters( 'previous_comments_link_attributes', '' );
	$rt.= "\" $attr>". preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';

	return $rt;
}

/* link-template.php の関数を改造 ここまで。 */
/* media.php の関数を改造 --- 直接出力せず値を返すようにした。 */
function previous_image_link_rt() {
	return adjacent_image_link_rt(true);
}

function next_image_link_rt() {
	return adjacent_image_link_rt(false);
}

function adjacent_image_link_rt($prev = true) {
	global $post;
	$post = get_post($post);
	$attachments = array_values(get_children("post_parent=$post->post_parent&post_type=attachment&post_mime_type=image&orderby=menu_order ASC, ID ASC"));

	foreach ( $attachments as $k => $attachment )
		if ( $attachment->ID == $post->ID )
			break;

	$k = $prev ? $k - 1 : $k + 1;

	if ( isset($attachments[$k]) )
		return wp_get_attachment_link($attachments[$k]->ID, 'thumbnail', true);
}

/* media.php の関数を改造 ここまで。 */

/* ブラウザ判別 */
function is_msie6_lalala() {
	$a=FALSE;
	$http_user_agent = getenv( "HTTP_USER_AGENT" );
	if( ereg( "^Mozilla.4", $http_user_agent ) ) {
		if( ereg( "MSIE 6", $http_user_agent )  ) {
			$a = TRUE;
		}elseif( ereg( "MSIE 7", $http_user_agent )  ) {
			$a = TRUE;
		}

	}
	return $a;
}




if ( function_exists('register_sidebar') )
    register_sidebar(array(
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));




function lalala_the_content($more_link_text = '(more...)', $stripteaser = 0, $more_file = '') {
	$content = get_the_content($more_link_text, $stripteaser, $more_file);
	$content = apply_filters('the_content', $content);
	$content = str_replace(']]>', ']]&gt;', $content);
	$content = lalala_replace_more($content);
	echo $content;
}
/*
アンカーいじり。中身が空のspanをなんとかする。
<p><span id="more-xx"></span></p><hoge>...
	-> <hoge id="more-xx">...
<p><span id="more-xx"></span>hoge hoge...
	-> <p id="more-xx">hoge hoge...
hoge hoge <span id="more-xx"></span> hoge...
	-> hoge hoge <span id="more-xx"> hoge...</span>
*/
function lalala_replace_more($content) {
	$output = '';
	if ( preg_match ("/<p><span id=\"(more-\d+)\"><\/span>\s*<\/p>/", $content, $matches)) {
		$pattern = $matches[0];
		$id = $matches[1];
		$str = explode($pattern, $content);
		$output = $str[0];
		if ($a=preg_replace ( "/^\s*<(\w+)/", "<$1 id=\"$id\" ", $str[1],1 )){
			$output .= $a;
		} else {
			$output .= "<p id=\"$id\" class=\"continue\">(Continuation)</p>".$str[1];
		}
	} elseif ( preg_match ("/<p><span id=\"(more-\d+)\"><\/span>/", $content, $matches)) {
		$pattern = $matches[0];
		$id = $matches[1];
		$str = explode($pattern, $content);
		$output = $str[0]."<p id=\"$id\">".$str[1];
	} elseif (preg_match ("/<span id=\"(more-\d+)\"><\/span>/", $content, $matches)) {
		$pattern = $matches[0];
		$id = $matches[1];
		$str = explode($pattern, $content);
		$output = $str[0]."<span id=\"$id\">";
		if ($a=preg_replace ( "/</", "</span><", $str[1], 1 )){
			$output .= $a;
		} else {		/* ありえないはず... */
			$output .= $str[1]."</span>";
		}
	} else {
		$output = $content;
	}

	return $output;
}




?>
